pub struct GoldenFixture {
pub account: &'static str,
pub module_id: &'static str,
pub bound_agent: &'static str,
pub foreign_agent: &'static str,
pub bound_room: &'static str,
pub unbound_room: &'static str,
pub system_credential: &'static str,
pub flow_engine_module: &'static str,
pub foreign_module: &'static str,
pub delivery_authority_module: &'static str,
}Fields
account: &'static strmodule_id: &'static strbound_agent: &'static strforeign_agent: &'static strbound_room: &'static strunbound_room: &'static strsystem_credential: &'static strInbox component of the system user in the golden.
flow_engine_module: &'static strModule id, and inbox component, of the flow engine in the golden.
foreign_module: &'static strA module that is neither the participant nor the flow engine; the golden refuses its event subjects and its durable to both.
Module id, and inbox component, of the delivery authority in the
golden; its ROOM durable is m_ followed by this id.